% test_your_model.m
% H. Garnier 
% 2/04/2024


clear;
close all;
clc

% Adjust the default value for the first-order model parameters below
K=0.5; % Model Gain
T=0.9; % Model time-constant



fontsize=12;

data_raw = importdata('DataOL_Tello.txt');

selectedColumns = data_raw(:, [1, 3, 5]);

% Define "time", "cmd" and  "speed" variable
t = selectedColumns(:,1);
Ts = mean(diff(t));
n0=round(20/Ts);
nf=round(59/Ts);

t = selectedColumns(n0:nf,1);
u = selectedColumns(n0:nf,2);
y0 = selectedColumns(n0:nf,3);




initial_speed=y0(3,1);
y=y0-initial_speed;   % Removal of the possibly non-zero initial angular speed 

M=tf(K,[T 1]);
t=(0:length(u)-1)*Ts;

yhat=lsim(M,u,t);

FIT = 100 * (1-norm(y-yhat)/norm(y-mean(y)));

figure
plot(t,y+initial_speed,t,yhat+initial_speed,'linewidth',2)
xlabel('time (s)')
legend('Measured ','Simulated','location','Northeast')
title(['Fit between the model and measured vertical speeds: ',num2str(FIT,'% 10.1f'),' %'])
set(gca,'FontSize',14,'FontName','helvetica');
xlim([0 t(end)])
grid
shg


